@@ -1,30 +1,27 @@
-import traceback
-from typing import Any, Callable, Coroutine, Generator, List, Optional, Tuple, Type, Union
 import asyncio
-from graia.broadcast.entities.decorator import Decorator
-from graia.broadcast.entities.dispatcher import BaseDispatcher
-from graia.broadcast.entities.exectarget import ExecTarget
-from graia.scheduler.exception import AlreadyStarted
-
-from graia.scheduler.utilles import EnteredRecord, print_track_async
-from .event import SchedulerTaskExecute
-from graia.broadcast import Broadcast
+import traceback
 from datetime import datetime
+from typing import Any, Callable, Generator, List, Optional
+
+from graia.broadcast import Broadcast
+from graia.broadcast.entities.decorator import Decorator
+from graia.broadcast.entities.exectarget import ExecTarget
+from graia.broadcast.typing import T_Dispatcher
+
+from graia.scheduler.exception import AlreadyStarted
+from graia.scheduler.utilles import EnteredRecord, print_track_async
+
 from . import Timer
 
+
 class SchedulerTask:
     target: Callable[..., Any]
     timer: Timer
     task: asyncio.Task
 
     broadcast: Broadcast
-    dispatchers: List[Union[
-        Type[BaseDispatcher],
-        Callable,
-        BaseDispatcher
-    ]]
+    dispatchers: List[T_Dispatcher]
     decorators: List[Decorator]
-    enableInternalAccess: bool = False
 
     cancelable: bool = False
     stoped: bool = False
@@ -37,38 +34,34 @@ class SchedulerTask:
     @property
     def is_sleeping(self) -> bool:
         return self.sleep_record.entered
-    
+
     @property
     def is_executing(self) -> bool:
         return not self.sleep_record.entered
-    
-    def __init__(self,
+
+    def __init__(
+        self,
         target: Callable[..., Any],
         timer: Timer,
         broadcast: Broadcast,
-        loop: asyncio.AbstractEventLoop,
+        loop: Optional[asyncio.AbstractEventLoop] = None,
         cancelable: bool = False,
-        dispatchers: Optional[List[Union[
-            Type[BaseDispatcher],
-            Callable,
-            BaseDispatcher
-        ]]] = None,
+        dispatchers: Optional[List[T_Dispatcher]] = None,
         decorators: Optional[List[Decorator]] = None,
-        enableInternalAccess: bool = False,
     ) -> None:
         self.target = target
         self.timer = timer
         self.broadcast = broadcast
-        self.loop = loop
+        self.loop = loop or asyncio.get_running_loop()
         self.cancelable = cancelable
         self.dispatchers = dispatchers or []
         self.decorators = decorators or []
-        self.enableInternalAccess = enableInternalAccess
         self.sleep_record = EnteredRecord()
         self.started_record = EnteredRecord()
 
     def setup_task(self) -> None:
-        if not self.started_record.entered: # 还未启动
+        """将本 SchedulerTask 作为 asyncio.Task 排入事件循环."""
+        if not self.started_record.entered:  # 还未启动
             self.task = self.loop.create_task(self.run())
         else:
             raise AlreadyStarted("the scheduler task has been started!")
@@ -80,30 +73,32 @@ class SchedulerTask:
             now = datetime.now()
             if next_execute_time >= now:
                 yield (next_execute_time - now).total_seconds()
-    
-    def coroutine_generator(self) -> Generator[Tuple[Coroutine, bool, Optional[float]], None, None]:
+
+    def coroutine_generator(self):
         for sleep_interval in self.sleep_interval_generator():
             yield (asyncio.sleep(sleep_interval), True, sleep_interval)
-            yield (self.broadcast.Executor(
-                target=ExecTarget(
-                    callable=self.target,
-                    inline_dispatchers=self.dispatchers,
-                    headless_decorators=self.decorators,
-                    enable_internal_access=self.enableInternalAccess
+            yield (
+                self.broadcast.Executor(
+                    target=ExecTarget(
+                        callable=self.target,
+                        inline_dispatchers=self.dispatchers,
+                        decorators=self.decorators,
+                    ),
                 ),
-                event=SchedulerTaskExecute()
-            ), False, None)
-    
+                False,
+                None,
+            )
+
     @print_track_async
     async def run(self) -> None:
         for coro, waiting, sleep_interval in self.coroutine_generator():
-            if waiting: # 是否为 asyncio.sleep 的 coro
+            if waiting:  # 是否为 asyncio.sleep 的 coro
                 with self.sleep_record:
                     try:
                         await coro
                     except asyncio.CancelledError:
                         return
-            else: # 执行
+            else:  # 执行
                 if self.cancelable:
                     try:
                         await coro
@@ -119,17 +114,23 @@ class SchedulerTask:
                     except Exception as e:
                         traceback.print_exc()
 
-    def stop_interval_gen(self) -> None:
+    def stop_gen_interval(self) -> None:
         if not self.stoped:
             self.stoped = True
-    
+
     async def join(self, stop=False):
+        """阻塞直至当前 SchedulerTask 执行完毕.
+
+        Args:
+            stop (bool, optional): 是否停止当前 SchedulerTask 下一次运行. 默认为 False.
+        """
         if stop and not self.stoped:
-            self.stop_interval_gen()
-        
+            self.stop_gen_interval()
+
         if self.task:
             await self.task
-    
+
     def stop(self):
+        """停止当前 SchedulerTask."""
         if not self.task.cancelled():
             self.task.cancel()
